from setuptools import setup

setup(
      name='chime_ml_ds',
      version='0.0.1',
      description='placeholder',
      author="x",
      author_email="x@x.com",
      url='http://github.com/example/example',
      packages=['chime_ml_ds'],
)